# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['vcrpy_encrypt']

package_data = \
{'': ['*']}

install_requires = \
['cryptography>=3.4.7,<4.0.0', 'vcrpy>=4.1.1,<5.0.0']

setup_kwargs = {
    'name': 'vcrpy-encrypt',
    'version': '0.9.0',
    'description': 'Encrypt vcrpy cassettes so they can be safely kept under version control.',
    'long_description': '[![PyPI](https://img.shields.io/pypi/v/vcrpy-encrypt)](https://pypi.org/project/vcrpy-encrypt/) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/vcrpy-encrypt)](https://pypi.org/project/vcrpy-encrypt/) [![CI Status](https://img.shields.io/github/workflow/status/CarloDePieri/vcrpy-encrypt/prod?logo=github)](https://github.com/CarloDePieri/vcrpy-encrypt/actions/workflows/prod.yml) [![Coverage Status](https://coveralls.io/repos/github/CarloDePieri/vcrpy-encrypt/badge.svg?branch=main)](https://coveralls.io/github/CarloDePieri/vcrpy-encrypt?branch=main) [![Maintenance](https://img.shields.io/maintenance/yes/2021)](https://github.com/CarloDePieri/vcrpy-encrypt/)\n\nEncrypt vcrpy cassettes so they can be safely kept under version control.\n\n## Rationale\n\nSensitive data can easily end up in HTTP requests/responses during testing.\n[Vcrpy](https://vcrpy.readthedocs.io/en/latest/index.html) has\n[a way to scrub that data](https://vcrpy.readthedocs.io/en/latest/advanced.html#filter-sensitive-data-from-the-request)\nfrom its cassettes, but sometimes the tests that logged them actually need that information to pass.\n\nThis would normally result in a choice: either don\'t record those test cassettes or don\'t keep them under version\ncontrol so that they can remain local only.\n\nEnters vcrpy-encrypt: at its core it\'s a simple\n[vcrpy persister](https://vcrpy.readthedocs.io/en/latest/advanced.html#register-your-own-cassette-persister) that will\nencrypt cassettes before writing them to disk and decrypt them before replaying them when needed by a test. This means\nthat tests can replay cassettes with sensitive data in them AND those cassettes can now be safely kept under version\ncontrol and shared with others.\n\n## Install\n\nSimply run:\n\n```bash\npip install vcrpy-encrypt\n```\n\n## Usage\n\n### Provide a secret key\n\nA secret key is needed to encrypt cassettes. It must be a 128, a 192 or a 256 bits long `bytes` object. vcrpy-encrypt\noffers an easy way to generate a random key:\n\n```bash\npython -c "from vcrpy_encrypt import generate_key; print(generate_key())"\n```\n\nBy default this will result in a 128 bits key, but `generate_key` can take `128` or `192` or `256` as argument to\ngenerate a longer key.\n\nIf a specific key is preferred, it can be converted from an utf-8, 16/24/32 characters long string like this:\n\n```python\nkey = "sixteensecretkey".encode("UTF-8")  # len(b\'sixteensecretkey\') == 16\n```\n\nNo matter the source, the key must be kept secret and separated from the code under version control!\n\n### Register the persister\n\nVcrpy\'s custom persister api needs a class reference. This class can be defined inheriting from\n`BaseEncryptedPersister` like this:\n\n```python\nfrom vcrpy_encrypt import BaseEncryptedPersister\n\nkey = ...  # recover the secret key from somewhere safe\n\nclass MyEncryptedPersister(BaseEncryptedPersister):\n    # the encryption_key field must be initialized here with the chosen key\n    encryption_key: bytes = key\n```\n\nThe encrypted persister can now be registered and used:\n\n```python\n# create a custom vcr object\nmy_vcr = vcr.VCR()\n\n# register the encrypted persister into the custom vcr object\nmy_vcr.register_persister(MyEncryptedPersister)\n\n# use that custom vcr object with use_cassette\nwith my_vcr.use_cassette("encoded-cassette"):\n    # this request will produce an encrypted cassette and will replay it on following runs\n    requests.get("https://localhost/?key=super-secret")\n```\n\nKeep in mind that multiple vcr objects can coexists, so it\'s possible to use the default vcr everywhere while\nreserving the one with the encrypted persister only for requests resulting in cassettes with sensitive data.\n\n## Customization\n\nSometimes it can be handy to inspect the content of a cassette. This can be done even for encrypted cassettes:\n\n```python\nclass MyEncryptedPersister(BaseEncryptedPersister):\n    encryption_key: bytes = key\n    should_output_clear_text_as_well = True\n```\n\nThe persister will output a clear text cassette side by side with the encrypted one. The clear text cassette will\nbe saved with a specific file extension (`.clear_text` by default): this will allow to blacklist the extension\nwithin the version control system to make sure not to share those files. For example for git:\n\n```bash\n# file: .gitignore\n*.clear_text\n```\n\nClear text cassettes are only useful for human inspection: the persister will still use only the encrypted ones to\nreplay network requests.\n\nIf different cassette file extensions are desired, they can be customized:\n\n```python\nclass MyEncryptedPersister(BaseEncryptedPersister):\n    encryption_key: bytes = key\n    should_output_clear_text_as_well = True\n    clear_text_suffix = ".custom_clear"\n    encoded_suffix = ".custom_enc"\n```\n\n## Encryption performance\n\nCurrently this library is encrypting cassettes using [cryptography](https://cryptography.io/) with [AES-GCM](https://cryptography.io/en/latest/hazmat/primitives/aead/#cryptography.hazmat.primitives.ciphers.aead.AESGCM). This algorithm\nimplementation is striking a good balance between security and performance.\n\nKeep in mind that key length will have an impact on encrypt time: 128 bits keys should suffice for most use cases.\n\n## Development\n\nInstall [invoke](http://pyinvoke.org/) and [poetry](https://python-poetry.org/):\n\n```bash\npip install invoke poetry\n```\n\nNow clone the git repo:\n\n```bash\ngit clone git@github.com:CarloDePieri/vcrpy-encrypt.git\ncd vcrpy-encrypt\ninv install\n```\n\nThis will try to create a virtualenv based on `python3.7` and install there all\nproject\'s dependencies. If a different python version is preferred, it can be\nselected by specifying  the `--python` (`-p`) flag like this:\n\n```bash\ninv install -p python3.8\n```\n\nThe test suite can be run with commands:\n\n```bash\ninv test         # run the test suite\ninv test-spec    # run the tests while showing the output as a spec document\ninv test-cov     # run the tests suite and produce a coverage report\n```\n\nTo run the test suite against all supported python version (they must be in path!) run:\n\n```bash\ninv test-all-python-version\n```\n\nTo test the github workflow with [act](https://github.com/nektos/act):\n\n```bash\n# First you need a .secrets file - do not version control this!\necho "repo_token: your_coveralls_token" > .secrets\n\n# Then you can run one of these:\ninv act-prod           # test the dev workflow\ninv act-prod -c shell  # open a shell in the act container (the above must fail first!)\ninv act-prod -c clean  # stop and delete a failed act container\n```\n',
    'author': 'Carlo De Pieri',
    'author_email': 'depieri.carlo@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/CarloDePieri/vcrpy-encrypt',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
